@@ -8,9 +8,20 @@ from allianceauth.services.hooks import get_extension_logger
 logger = get_extension_logger(__name__)
 
 
+class General(models.Model):
+    class Meta:
+        managed = False
+        default_permissions = ()
+        permissions = (
+            ("access_pve", "Can access pve pages and be added in entries"),
+            ('manage_entries', "Can do CRUD operations with entries"),
+            ("manage_rotations", "Can do CRUD operations with rotations"),
+        )
+
+
 class RotationQueryset(models.QuerySet):
     def get_setup_summary(self):
-        return RotationSetupSummary.objects.filter(rotation__in=self).order_by().values('character')\
+        return RotationSetupSummary.objects.filter(rotation__in=self).order_by().values('user')\
             .annotate(total_setups=Coalesce(models.Sum('valid_setups'), 0))\
 
 
@@ -31,7 +42,7 @@ class Rotation(models.Model):
     max_daily_setups = models.PositiveSmallIntegerField(default=1, help_text='The maximum number of helped setup per day. If more are submitted, only this number is counted. 0 for deactivating helped setups.')
     min_people_share_setup = models.PositiveSmallIntegerField(default=3, help_text='The minimum number of people in an entry to consider the helped setup valid.')
 
-    tax_rate = models.FloatField(default=0)
+    tax_rate = models.FloatField(default=0, help_text='Tax rate in percentage')
     is_closed = models.BooleanField(default=False)
     is_paid_out = models.BooleanField(default=False)
 
@@ -44,8 +55,8 @@ class Rotation(models.Model):
 
     @property
     def summary(self):
-        setup_summary = Rotation.objects.filter(pk=self.pk).get_setup_summary().filter(character_id=models.OuterRef('character_id')).values('total_setups')
-        return EntryCharacter.objects.filter(entry__rotation=self).values('character').order_by()\
+        setup_summary = Rotation.objects.filter(pk=self.pk).get_setup_summary().filter(user_id=models.OuterRef('user_id')).values('total_setups')
+        return EntryCharacter.objects.filter(entry__rotation=self).values('user').order_by()\
             .annotate(helped_setups=Coalesce(models.Subquery(setup_summary[:1]), 0))\
             .annotate(estimated_total=models.Sum('estimated_share_total'))\
             .annotate(actual_total=models.Sum('actual_share_total'))
@@ -67,16 +78,13 @@ class Rotation(models.Model):
         return f'{self.pk} {self.name}'
 
     class Meta:
-        default_permissions = ('add', 'change', 'view')
-        permissions = [
-            ('close', 'Can close rotations'),
-        ]
+        default_permissions = ()
 
 
 class EntryCharacter(models.Model):
     share_count = models.PositiveIntegerField(default=1)
     entry = models.ForeignKey('Entry', on_delete=models.CASCADE, related_name='ratting_shares')
-    character = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, related_name='ratting_shares')
+    user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, related_name='ratting_shares')
     helped_setup = models.BooleanField(default=False)
     estimated_share_total = models.FloatField(default=0)
     actual_share_total = models.FloatField(default=0)
@@ -90,9 +98,7 @@ class EntryCharacter(models.Model):
         return (self.entry.actual_total_after_tax / self.entry.total_shares_count) * self.share_count
 
     class Meta:
-        constraints = [
-            models.UniqueConstraint(fields=['entry', 'character'], name='unique_character'),
-        ]
+        default_permissions = ()
 
 
 class Entry(models.Model):
@@ -136,14 +142,18 @@ class Entry(models.Model):
                     actual_share_total=(models.F('actual_total_after_tax') / models.Value(shares_count)) * models.F('share_count')
                 )
 
+    class Meta:
+        default_permissions = ()
+
 
 class RotationSetupSummary(models.Model):
     id = models.BigIntegerField(primary_key=True)
-    rotation = models.ForeignKey(Rotation, on_delete=models.CASCADE, related_name='+')
-    character = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, related_name='rotations_stats')
+    rotation = models.ForeignKey(Rotation, on_delete=models.DO_NOTHING, related_name='+')
+    user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.DO_NOTHING, related_name='rotations_stats')
     entry_date = models.DateField()
     valid_setups = models.IntegerField()
 
     class Meta:
         managed = False  # this is a view, check 0003
         db_table = 'allianceauth_pve_setup_summary'
+        default_permissions = ()
